asr.test.mocks.gpaw.spinorbit
=============================

.. automodule:: asr.test.mocks.gpaw.spinorbit

   
   
   .. rubric:: Functions

   
   .. autofunction:: soc_eigenstates
   
   

   
   
   .. rubric:: Classes

   
   .. autoclass:: SOC
      :members:
   
   

   
   
   